<template>
  <div class="card">
    <div class="card-body">
      <h4
        class="card-title"
        :class="$i18n.locale == 'ar' ? 'font-size-15' : ''"
      >
        {{ $t("app.owner_user") }}
      </h4>
      <div class="col-md-12" style="padding: 0">
        <span
          v-if="userLoading"
          class="spinner-grow spinner-grow-sm mr-1"
          role="status"
          aria-hidden="true"
        >
        </span>
        <select
          v-if="!userLoading"
          id="menu"
          class="form-control"
          v-model="row.user_id"
          v-on:input="onUserChange"
        >
          <option v-for="(usr, idx) in users" :key="idx" :value="usr.id">
            {{ usr.name }}
          </option>
        </select>
      </div>
    </div>
  </div>
</template>

<script>
import iziToast from "izitoast";

export default {
  name: "CardUsers",
  props: ["user_id"],
  data() {
    return {
      auth: {
        id_token: "",
      },
      row: {
        user_id: this.$props.user_id,
      },
      users: [],
      userLoading: true,
    };
  },
  created() {
    if (localStorage.getItem("id_token")) {
      this.auth.id_token = localStorage.getItem("id_token");
    }

    this.fetchUsers();
  },
  methods: {
    onUserChange() {
      const data = {
        user_id: this.row.user_id,
      };
      this.$emit("userChange", data);
    },

    fetchUsers() {
      this.userLoading = true;
      this.axios.defaults.headers.common = {
        "X-Requested-With": "XMLHttpRequest", // security to prevent CSRF attacks
        Authorization: `Bearer ` + this.auth.id_token,
      };
      const options = {
        url: "/users",
        method: "GET",
        data: {},
        params: {
          paginate: 100,
        },
      };
      this.axios(options)
        .then((res) => {
          this.userLoading = false;
          this.users = res.data.rows;
        })
        .catch((err) => {
          this.userLoading = false;
          iziToast.warning({
            icon: "bx bx-angry",
            title: "",
            message: err.response ? err.response.data.message : "" + err,
          });
        });
    },
  },
};
</script>
